@@ -19,7 +19,7 @@
 
 package FindBin::libs;
 
-use v5.10;
+use v5.14;
 use strict;
 
 use FindBin;
@@ -27,8 +27,9 @@ use Symbol;
 
 use File::Basename;
 
-use Carp    qw( croak           );
-use Symbol  qw( qualify_to_ref  );
+use Carp        qw( croak           );
+use List::Util  qw( first           );
+use Symbol      qw( qualify_to_ref  );
 
 use File::Spec::Functions
 qw
@@ -53,30 +54,42 @@ BEGIN
     # cannot handle the rooted system being linked
     # back to itself.
 
-    use Cwd qw( &abs_path &cwd );
+    use Cwd qw( &cwd );
 
-    unless( eval {abs_path '//';  abs_path cwd } )
+    my $abs = Cwd->can( 'abs_path'  )
+    or die "Odd: Cwd cannot 'abs_path'\n";
+
+    if
+    (
+        eval { $abs->( '//' );  $abs->( cwd ); 1 }
+    )
     {
-        # abs_path seems to be having problems,
-        # fix is to stub it out.
-        #
-        # undef avoids nastygram.
+        # nothing more to do: abs_path works.
+    }
+    elsif
+    (
+        $abs = File::Spec::Functions->can( 'rel2abs'  )
+    )
+    {
+        # ok, we have a substitute
+    }
+    else
+    {
+        die "Non-working abs_path without 'rel2abs'\n";
+    }
 
-        my $ref = qualify_to_ref 'abs_path', __PACKAGE__;
+    my $ref = *{ qualify_to_ref 'abs_path', __PACKAGE__ };
 
-        my $sub = File::Spec::Functions->can( 'rel2abs' );
+    undef &{ *$ref };
 
-        undef &{ $ref };
-
-        *$ref = $sub
-    };
+    *{ $ref } = $abs;
 }
 
 ########################################################################
 # package variables 
 ########################################################################
 
-our $VERSION = v1.63;
+our $VERSION = v1.64.2;
 
 my %defaultz = 
 (
@@ -224,23 +237,16 @@ my $handle_args
     {
         my ( $k, $v ) = split '=', $_, 2;
 
-        given( $k )
-        {
-            when( @use_undef )
-            {
-                # leave $v undef.
-            }
-
-            # generic handling: default if 1 if no value
-            # is provided,
-
-            $v  //= 1;
-        }
+        defined $v
+        or 
+        first { $_ eq $k } @use_undef 
+        or 
+        $v  //= 1;
 
         # "no" inverts the sense of the test.
 
-        $k =~ s{^no}{}
-        and $v  = ! $v;
+        index $k, 'no'
+        or $v  = ! $v;
 
         ( $k => $v )
     }
